@@ -42,18 +42,24 @@ fn fetch_spot_markets_raw() -> Vec<SpotMarket> {
 fn verify_spot_symbols() {
     let markets = fetch_spot_markets_raw();
     for market in markets.iter() {
-        let pair = normalize_pair(&market.wsname.clone().unwrap(), EXCHANGE_NAME).unwrap();
+        let pair1 = normalize_pair(&market.wsname.clone().unwrap(), EXCHANGE_NAME).unwrap();
+        let pair2 = normalize_pair(&market.altname, EXCHANGE_NAME).unwrap();
         let pair_expected = format!(
             "{}/{}",
             normalize_currency(&market.base, EXCHANGE_NAME),
             normalize_currency(&market.quote, EXCHANGE_NAME)
         );
 
-        assert_eq!(pair.as_str(), pair_expected);
+        assert_eq!(pair1.as_str(), pair_expected);
+        assert_eq!(pair2.as_str(), pair_expected);
         assert_eq!(
             MarketType::Spot,
             get_market_type(&market.wsname.clone().unwrap(), EXCHANGE_NAME, None)
         );
+        assert_eq!(
+            MarketType::Spot,
+            get_market_type(&market.altname, EXCHANGE_NAME, None)
+        );
     }
 }
 
